@@ -1,45 +1,15 @@
-package Email::Address;
 use strict;
-## no critic RequireUseWarnings
-# support pre-5.6
+use warnings;
+package Email::Address;
+{
+  $Email::Address::VERSION = '1.899';
+}
+# ABSTRACT: RFC 2822 Address Parsing and Creation
 
-use vars qw[$VERSION $COMMENT_NEST_LEVEL $STRINGIFY
-            $COLLAPSE_SPACES
-            %PARSE_CACHE %FORMAT_CACHE %NAME_CACHE
-            $addr_spec $angle_addr $name_addr $mailbox];
+our $COMMENT_NEST_LEVEL ||= 2;
+our $STRINGIFY          ||= 'format';
+our $COLLAPSE_SPACES      = 1 unless defined $COLLAPSE_SPACES; # I miss //=
 
-my $NOCACHE;
-
-$VERSION              = '1.897';
-$COMMENT_NEST_LEVEL ||= 2;
-$STRINGIFY          ||= 'format';
-$COLLAPSE_SPACES      = 1 unless defined $COLLAPSE_SPACES; # who wants //=? me!
-
-=head1 NAME
-
-Email::Address - RFC 2822 Address Parsing and Creation
-
-=head1 SYNOPSIS
-
-  use Email::Address;
-
-  my @addresses = Email::Address->parse($line);
-  my $address   = Email::Address->new(Casey => 'casey@localhost');
-
-  print $address->format;
-
-=head1 VERSION
-
-version 1.897
-
-=head1 DESCRIPTION
-
-This class implements a regex-based RFC 2822 parser that locates email
-addresses in strings and returns a list of C<Email::Address> objects found.
-Alternatively you may construct objects manually. The goal of this software is
-to be correct, and very very fast.
-
-=cut
 
 my $CTL            = q{\x00-\x1F\x7F};
 my $special        = q{()<>\\[\\]:;@\\\\,."};
@@ -92,57 +62,11 @@ my $domain         = qr/$dot_atom|$domain_literal/;
 
 my $display_name   = $phrase;
 
-=head2 Package Variables
 
-B<ACHTUNG!>  Email isn't easy (if even possible) to parse with a regex, I<at
-least> if you're on a C<perl> prior to 5.10.0.  Providing regular expressions
-for use by other programs isn't a great idea, because it makes it hard to
-improve the parser without breaking the "it's a regex" feature.  Using these
-regular expressions is not encouraged, and methods like C<<
-Email::Address->is_addr_spec >> should be provided in the future.
-
-Several regular expressions used in this package are useful to others.
-For convenience, these variables are declared as package variables that
-you may access from your program.
-
-These regular expressions conform to the rules specified in RFC 2822.
-
-You can access these variables using the full namespace. If you want
-short names, define them yourself.
-
-  my $addr_spec = $Email::Address::addr_spec;
-
-=over 4
-
-=item $Email::Address::addr_spec
-
-This regular expression defined what an email address is allowed to
-look like.
-
-=item $Email::Address::angle_addr
-
-This regular expression defines an C<$addr_spec> wrapped in angle
-brackets.
-
-=item $Email::Address::name_addr
-
-This regular expression defines what an email address can look like
-with an optional preceding display name, also known as the C<phrase>.
-
-=item $Email::Address::mailbox
-
-This is the complete regular expression defining an RFC 2822 emial
-address with an optional preceding display name and optional
-following comment.
-
-=back
-
-=cut
-
-$addr_spec  = qr/$local_part\@$domain/;
-$angle_addr = qr/$cfws*<$addr_spec>$cfws*/;
-$name_addr  = qr/$display_name?$angle_addr/;
-$mailbox    = qr/(?:$name_addr|$addr_spec)$comment*/;
+our $addr_spec  = qr/$local_part\@$domain/;
+our $angle_addr = qr/$cfws*<$addr_spec>$cfws*/;
+our $name_addr  = qr/$display_name?$angle_addr/;
+our $mailbox    = qr/(?:$name_addr|$addr_spec)$comment*/;
 
 sub _PHRASE   () { 0 }
 sub _ADDRESS  () { 1 }
@@ -150,41 +74,9 @@ sub _COMMENT  () { 2 }
 sub _ORIGINAL () { 3 }
 sub _IN_CACHE () { 4 }
 
-=head2 Class Methods
 
-=over 4
-
-=item parse
-
-  my @addrs = Email::Address->parse(
-    q[me@local, Casey <me@local>, "Casey" <me@local> (West)]
-  );
-
-This method returns a list of C<Email::Address> objects it finds
-in the input string.
-
-The specification for an email address allows for infinitley
-nestable comments. That's nice in theory, but a little over done.
-By default this module allows for two (C<2>) levels of nested
-comments. If you think you need more, modify the
-C<$Email::Address::COMMENT_NEST_LEVEL> package variable to allow
-more.
-
-  $Email::Address::COMMENT_NEST_LEVEL = 10; # I'm deep
-
-The reason for this hardly-limiting limitation is simple: efficiency.
-
-Long strings of whitespace can be problematic for this module to parse, a bug
-which has not yet been adequately addressed.  The default behavior is now to
-collapse multiple spaces into a single space, which avoids this problem.  To
-prevent this behavior, set C<$Email::Address::COLLAPSE_SPACES> to zero.  This
-variable will go away when the bug is resolved properly.
-
-In accordance with RFC 822 and its descendants, this module demands that email
-addresses be ASCII only.  Any non-ASCII content in the parsed addresses will
-cause the parser to return no results.
-
-=cut
+our (%PARSE_CACHE, %FORMAT_CACHE, %NAME_CACHE);
+my $NOCACHE;
 
 sub __get_cached_parse {
     return if $NOCACHE;
@@ -250,8 +142,247 @@ sub parse {
     return @addrs;
 }
 
+
+sub new {
+  my ($class, $phrase, $email, $comment, $orig) = @_;
+  $phrase =~ s/\A"(.+)"\z/$1/ if $phrase;
+
+  bless [ $phrase, $email, $comment, $orig ] => $class;
+}
+
+
+sub purge_cache {
+    %NAME_CACHE   = ();
+    %FORMAT_CACHE = ();
+    %PARSE_CACHE  = ();
+}
+
+
+sub disable_cache {
+  my ($class) = @_;
+  $class->purge_cache;
+  $NOCACHE = 1;
+}
+
+sub enable_cache {
+  $NOCACHE = undef;
+}
+
+
+BEGIN {
+  my %_INDEX = (
+    phrase   => _PHRASE,
+    address  => _ADDRESS,
+    comment  => _COMMENT,
+    original => _ORIGINAL,
+  );
+
+  for my $method (keys %_INDEX) {
+    no strict 'refs';
+    my $index = $_INDEX{ $method };
+    *$method = sub {
+      if ($_[1]) {
+        if ($_[0][_IN_CACHE]) {
+          my $replicant = bless [ @{$_[0]} ] => ref $_[0];
+          $PARSE_CACHE{ ${ $_[0][_IN_CACHE][0] } }[ $_[0][_IN_CACHE][1] ]
+            = $replicant;
+          $_[0][_IN_CACHE] = undef;
+        }
+        $_[0]->[ $index ] = $_[1];
+      } else {
+        $_[0]->[ $index ];
+      }
+    };
+  }
+}
+
+sub host { ($_[0]->[_ADDRESS] =~ /\@($domain)/o)[0]     }
+sub user { ($_[0]->[_ADDRESS] =~ /($local_part)\@/o)[0] }
+
+
+sub format {
+    my $cache_str = do { no warnings 'uninitialized'; "@{$_[0]}" };
+    return $FORMAT_CACHE{$cache_str} if exists $FORMAT_CACHE{$cache_str};
+    $FORMAT_CACHE{$cache_str} = $_[0]->_format;
+}
+
+sub _format {
+    my ($self) = @_;
+
+    unless (
+      defined $self->[_PHRASE] && length $self->[_PHRASE]
+      ||
+      defined $self->[_COMMENT] && length $self->[_COMMENT]
+    ) {
+        return $self->[_ADDRESS];
+    }
+
+    my $format = sprintf q{%s <%s> %s},
+                 $self->_enquoted_phrase,
+                 (defined $self->[_ADDRESS] ? $self->[_ADDRESS] : ''),
+                 (defined $self->[_COMMENT] ? $self->[_COMMENT] : '');
+
+    $format =~ s/^\s+//;
+    $format =~ s/\s+$//;
+
+    return $format;
+}
+
+sub _enquoted_phrase {
+  my ($self) = @_;
+
+  my $phrase = $self->[_PHRASE];
+
+  # if it's encoded -- rjbs, 2007-02-28
+  return $phrase if $phrase =~ /\A=\?.+\?=\z/;
+
+  $phrase =~ s/\A"(.+)"\z/$1/;
+  $phrase =~ s/([\\"])/\\$1/g;
+
+  return qq{"$phrase"};
+}
+
+
+sub name {
+    my $cache_str = do { no warnings 'uninitialized'; "@{$_[0]}" };
+    return $NAME_CACHE{$cache_str} if exists $NAME_CACHE{$cache_str};
+
+    my ($self) = @_;
+    my $name = q{};
+    if ( $name = $self->[_PHRASE] ) {
+        $name =~ s/^"//;
+        $name =~ s/"$//;
+        $name =~ s/($quoted_pair)/substr $1, -1/goe;
+    } elsif ( $name = $self->[_COMMENT] ) {
+        $name =~ s/^\(//;
+        $name =~ s/\)$//;
+        $name =~ s/($quoted_pair)/substr $1, -1/goe;
+        $name =~ s/$comment/ /go;
+    } else {
+        ($name) = $self->[_ADDRESS] =~ /($local_part)\@/o;
+    }
+    $NAME_CACHE{$cache_str} = $name;
+}
+
+
+sub as_string {
+  warn 'altering $Email::Address::STRINGIFY is deprecated; subclass instead'
+    if $STRINGIFY ne 'format';
+
+  $_[0]->can($STRINGIFY)->($_[0]);
+}
+
+use overload '""' => 'as_string', fallback => 1;
+
+
+1;
+
+__END__
+
 =pod
 
+=head1 NAME
+
+Email::Address - RFC 2822 Address Parsing and Creation
+
+=head1 VERSION
+
+version 1.899
+
+=head1 SYNOPSIS
+
+  use Email::Address;
+
+  my @addresses = Email::Address->parse($line);
+  my $address   = Email::Address->new(Casey => 'casey@localhost');
+
+  print $address->format;
+
+=head1 DESCRIPTION
+
+This class implements a regex-based RFC 2822 parser that locates email
+addresses in strings and returns a list of C<Email::Address> objects found.
+Alternatively you may construct objects manually. The goal of this software is
+to be correct, and very very fast.
+
+=head2 Package Variables
+
+B<ACHTUNG!>  Email isn't easy (if even possible) to parse with a regex, I<at
+least> if you're on a C<perl> prior to 5.10.0.  Providing regular expressions
+for use by other programs isn't a great idea, because it makes it hard to
+improve the parser without breaking the "it's a regex" feature.  Using these
+regular expressions is not encouraged, and methods like C<<
+Email::Address->is_addr_spec >> should be provided in the future.
+
+Several regular expressions used in this package are useful to others.
+For convenience, these variables are declared as package variables that
+you may access from your program.
+
+These regular expressions conform to the rules specified in RFC 2822.
+
+You can access these variables using the full namespace. If you want
+short names, define them yourself.
+
+  my $addr_spec = $Email::Address::addr_spec;
+
+=over 4
+
+=item $Email::Address::addr_spec
+
+This regular expression defined what an email address is allowed to
+look like.
+
+=item $Email::Address::angle_addr
+
+This regular expression defines an C<$addr_spec> wrapped in angle
+brackets.
+
+=item $Email::Address::name_addr
+
+This regular expression defines what an email address can look like
+with an optional preceding display name, also known as the C<phrase>.
+
+=item $Email::Address::mailbox
+
+This is the complete regular expression defining an RFC 2822 email
+address with an optional preceding display name and optional
+following comment.
+
+=back
+
+=head2 Class Methods
+
+=over
+
+=item parse
+
+  my @addrs = Email::Address->parse(
+    q[me@local, Casey <me@local>, "Casey" <me@local> (West)]
+  );
+
+This method returns a list of C<Email::Address> objects it finds in the input
+string.  B<Please note> that it returns a list, and expects that it may find
+multiple addresses.  The behavior in scalar context is undefined.
+
+The specification for an email address allows for infinitely nestable comments.
+That's nice in theory, but a little over done.  By default this module allows
+for two (C<2>) levels of nested comments. If you think you need more, modify
+the C<$Email::Address::COMMENT_NEST_LEVEL> package variable to allow more.
+
+  $Email::Address::COMMENT_NEST_LEVEL = 10; # I'm deep
+
+The reason for this hardly-limiting limitation is simple: efficiency.
+
+Long strings of whitespace can be problematic for this module to parse, a bug
+which has not yet been adequately addressed.  The default behavior is now to
+collapse multiple spaces into a single space, which avoids this problem.  To
+prevent this behavior, set C<$Email::Address::COLLAPSE_SPACES> to zero.  This
+variable will go away when the bug is resolved properly.
+
+In accordance with RFC 822 and its descendants, this module demands that email
+addresses be ASCII only.  Any non-ASCII content in the parsed addresses will
+cause the parser to return no results.
+
 =item new
 
   my $address = Email::Address->new(undef, 'casey@local');
@@ -263,17 +394,6 @@ positional arguments: phrase, email, and comment, and original string.
 
 The original string should only really be set using C<parse>.
 
-=cut
-
-sub new {
-  my ($class, $phrase, $email, $comment, $orig) = @_;
-  $phrase =~ s/\A"(.+)"\z/$1/ if $phrase;
-
-  bless [ $phrase, $email, $comment, $orig ] => $class;
-}
-
-=pod
-
 =item purge_cache
 
   Email::Address->purge_cache;
@@ -285,14 +405,6 @@ people, this class method will empty those caches.
 
 I've loaded over 12000 objects and not encountered a memory problem.
 
-=cut
-
-sub purge_cache {
-    %NAME_CACHE   = ();
-    %FORMAT_CACHE = ();
-    %PARSE_CACHE  = ();
-}
-
 =item disable_cache
 
 =item enable_cache
@@ -303,20 +415,6 @@ If you'd rather not cache address parses at all, you can disable (and
 re-enable) the Email::Address cache with these methods.  The cache is enabled
 by default.
 
-=cut
-
-sub disable_cache {
-  my ($class) = @_;
-  $class->purge_cache;
-  $NOCACHE = 1;
-}
-
-sub enable_cache {
-  $NOCACHE = undef;
-}
-
-=pod
-
 =back
 
 =head2 Instance Methods
@@ -363,40 +461,6 @@ Accessor for the host portion of an address's address.
 
 Accessor for the user portion of an address's address.
 
-=cut
-
-BEGIN {
-  my %_INDEX = (
-    phrase   => _PHRASE,
-    address  => _ADDRESS,
-    comment  => _COMMENT,
-    original => _ORIGINAL,
-  );
-
-  for my $method (keys %_INDEX) {
-    no strict 'refs';
-    my $index = $_INDEX{ $method };
-    *$method = sub {
-      if ($_[1]) {
-        if ($_[0][_IN_CACHE]) {
-          my $replicant = bless [ @{$_[0]} ] => ref $_[0];
-          $PARSE_CACHE{ ${ $_[0][_IN_CACHE][0] } }[ $_[0][_IN_CACHE][1] ]
-            = $replicant;
-          $_[0][_IN_CACHE] = undef;
-        }
-        $_[0]->[ $index ] = $_[1];
-      } else {
-        $_[0]->[ $index ];
-      }
-    };
-  }
-}
-
-sub host { ($_[0]->[_ADDRESS] =~ /\@($domain)/o)[0]     }
-sub user { ($_[0]->[_ADDRESS] =~ /($local_part)\@/o)[0] }
-
-=pod
-
 =item format
 
   my $printable = $address->format;
@@ -404,50 +468,6 @@ sub user { ($_[0]->[_ADDRESS] =~ /($local_part)\@/o)[0] }
 Returns a properly formatted RFC 2822 address representing the
 object.
 
-=cut
-
-sub format {
-    local $^W = 0; ## no critic
-    return $FORMAT_CACHE{"@{$_[0]}"} if exists $FORMAT_CACHE{"@{$_[0]}"};
-    $FORMAT_CACHE{"@{$_[0]}"} = $_[0]->_format;
-}
-
-sub _format {
-    my ($self) = @_;
-
-    unless (
-      defined $self->[_PHRASE] && length $self->[_PHRASE]
-      ||
-      defined $self->[_COMMENT] && length $self->[_COMMENT]
-    ) {
-        return $self->[_ADDRESS];
-    }
-
-    my $format = sprintf q{%s <%s> %s},
-                 $self->_enquoted_phrase, $self->[_ADDRESS], $self->[_COMMENT];
-
-    $format =~ s/^\s+//;
-    $format =~ s/\s+$//;
-
-    return $format;
-}
-
-sub _enquoted_phrase {
-  my ($self) = @_;
-
-  my $phrase = $self->[_PHRASE];
-
-  # if it's encoded -- rjbs, 2007-02-28
-  return $phrase if $phrase =~ /\A=\?.+\?=\z/;
-
-  $phrase =~ s/\A"(.+)"\z/$1/;
-  $phrase =~ s/([\\"])/\\$1/g;
-
-  return qq{"$phrase"};
-}
-
-=pod
-
 =item name
 
   my $name = $address->name;
@@ -461,30 +481,6 @@ This method does B<not> try to massage any name it identifies and instead
 leaves that up to someone else. Who is it to decide if someone wants their
 name capitalized, or if they're Irish?
 
-=cut
-
-sub name {
-    local $^W = 0;
-    return $NAME_CACHE{"@{$_[0]}"} if exists $NAME_CACHE{"@{$_[0]}"};
-    my ($self) = @_;
-    my $name = q{};
-    if ( $name = $self->[_PHRASE] ) {
-        $name =~ s/^"//;
-        $name =~ s/"$//;
-        $name =~ s/($quoted_pair)/substr $1, -1/goe;
-    } elsif ( $name = $self->[_COMMENT] ) {
-        $name =~ s/^\(//;
-        $name =~ s/\)$//;
-        $name =~ s/($quoted_pair)/substr $1, -1/goe;
-        $name =~ s/$comment/ /go;
-    } else {
-        ($name) = $self->[_ADDRESS] =~ /($local_part)\@/o;
-    }
-    $NAME_CACHE{"@{$_[0]}"} = $name;
-}
-
-=pod
-
 =back
 
 =head2 Overloaded Operators
@@ -512,27 +508,8 @@ don't.
 Modifying this package variable is now deprecated. Subclassing is now the
 recommended approach.
 
-=cut
-
-sub as_string {
-  warn 'altering $Email::Address::STRINGIFY is deprecated; subclass instead'
-    if $STRINGIFY ne 'format';
-
-  $_[0]->can($STRINGIFY)->($_[0]);
-}
-
-use overload '""' => 'as_string';
-
-=pod
-
 =back
 
-=cut
-
-1;
-
-__END__
-
 =head2 Did I Mention Fast?
 
 On his 1.8GHz Apple MacBook, rjbs gets these results:
@@ -556,31 +533,34 @@ On his 1.8GHz Apple MacBook, rjbs gets these results:
 certain known characteristics, and disabling cache will also degrade
 performance.
 
-=head1 PERL EMAIL PROJECT
+=head1 VERSION
 
-This module is maintained by the Perl Email Project
-
-L<http://emailproject.perl.org/wiki/Email::Address>
-
-=head1 SEE ALSO
-
-L<Email::Simple>, L<perl>.
-
-=head1 AUTHOR
-
-Originally by Casey West, <F<casey@geeknest.com>>.
-
-Maintained, 2006-2007, Ricardo SIGNES <F<rjbs@cpan.org>>.
+version 1.898
 
 =head1 ACKNOWLEDGEMENTS
 
-Thanks to Kevin Riggle and Tatsuhiko Miyagawa for tests for annoying phrase-quoting bugs!
+Thanks to Kevin Riggle and Tatsuhiko Miyagawa for tests for annoying
+phrase-quoting bugs!
 
-=head1 COPYRIGHT
+=head1 AUTHORS
 
-Copyright (c) 2004 Casey West.  All rights reserved.  This module is free
-software; you can redistribute it and/or modify it under the same terms as Perl
-itself.
+=over 4
+
+=item *
+
+Casey West
+
+=item *
+
+Ricardo SIGNES <rjbs@cpan.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2004 by Casey West.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
